@@ -143,10 +143,10 @@ def doParseCommand(url):
                     if ret.find(',') > -1:
                         tmpParam = ret.split(',')
                         print 'lat:' + tmpParam[0]
-                        print 'long:' + tmpParam[1]
+                        print 'long:' + tmpParam[1][0:-1]
                         
                         tmpLocation = tmpParam[1]+','+tmpParam[0]
-            
+                        
                         tmpParams = urllib.urlencode({"userid": VAR_USERID, "password": VAR_PASSWORD, "location": tmpLocation })
                         tmpHeaders = {"Content-Type":"application/x-www-form-urlencoded", "Connection":"Keep-Alive"}
                         ObjHttp = httplib.HTTPConnection(API_HOST)
@@ -217,6 +217,8 @@ def doParseResponse(strer):
         file_object.writelines(strer)
         file_object.close()
         
+        doParseLogin()
+        
 def doParseMessage():
     global VAR_USERID, VAR_USERNAME, VAR_PASSWORD
     
